@@ -32,8 +32,10 @@ from .paginator import (
     GetCostEstimationPaginator,
     GetResourceCollectionPaginator,
     ListAnomaliesForInsightPaginator,
+    ListAnomalousLogGroupsPaginator,
     ListEventsPaginator,
     ListInsightsPaginator,
+    ListMonitoredResourcesPaginator,
     ListNotificationChannelsPaginator,
     ListOrganizationInsightsPaginator,
     ListRecommendationsPaginator,
@@ -59,10 +61,13 @@ from .type_defs import (
     GetResourceCollectionResponseTypeDef,
     InsightFeedbackTypeDef,
     ListAnomaliesForInsightResponseTypeDef,
+    ListAnomalousLogGroupsResponseTypeDef,
     ListEventsFiltersTypeDef,
     ListEventsResponseTypeDef,
     ListInsightsResponseTypeDef,
     ListInsightsStatusFilterTypeDef,
+    ListMonitoredResourcesFiltersTypeDef,
+    ListMonitoredResourcesResponseTypeDef,
     ListNotificationChannelsResponseTypeDef,
     ListOrganizationInsightsResponseTypeDef,
     ListRecommendationsResponseTypeDef,
@@ -139,6 +144,14 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#close)
+        """
+
     def delete_insight(self, *, Id: str) -> Dict[str, Any]:
         """
         Deletes the insight along with the associated anomalies, events and
@@ -318,6 +331,16 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#list_anomalies_for_insight)
         """
 
+    def list_anomalous_log_groups(
+        self, *, InsightId: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListAnomalousLogGroupsResponseTypeDef:
+        """
+        Returns the list of log groups that contain log anomalies.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.list_anomalous_log_groups)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#list_anomalous_log_groups)
+        """
+
     def list_events(
         self,
         *,
@@ -348,6 +371,21 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#list_insights)
         """
 
+    def list_monitored_resources(
+        self,
+        *,
+        Filters: ListMonitoredResourcesFiltersTypeDef,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> ListMonitoredResourcesResponseTypeDef:
+        """
+        Returns the list of all log groups that are being monitored and tagged by DevOps
+        Guru.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.list_monitored_resources)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#list_monitored_resources)
+        """
+
     def list_notification_channels(
         self, *, NextToken: str = ...
     ) -> ListNotificationChannelsResponseTypeDef:
@@ -532,6 +570,15 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_anomalous_log_groups"]
+    ) -> ListAnomalousLogGroupsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(self, operation_name: Literal["list_events"]) -> ListEventsPaginator:
         """
@@ -546,6 +593,15 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["list_monitored_resources"]
+    ) -> ListMonitoredResourcesPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["list_notification_channels"]
