@@ -39,15 +39,20 @@ __all__ = (
     "InsightStatusType",
     "InsightTypeType",
     "ListAnomaliesForInsightPaginatorName",
+    "ListAnomalousLogGroupsPaginatorName",
     "ListEventsPaginatorName",
     "ListInsightsPaginatorName",
+    "ListMonitoredResourcesPaginatorName",
     "ListNotificationChannelsPaginatorName",
     "ListOrganizationInsightsPaginatorName",
     "ListRecommendationsPaginatorName",
     "LocaleType",
+    "LogAnomalyTypeType",
     "OptInStatusType",
     "OrganizationResourceCollectionTypeType",
     "ResourceCollectionTypeType",
+    "ResourcePermissionType",
+    "ResourceTypeFilterType",
     "SearchInsightsPaginatorName",
     "SearchOrganizationInsightsPaginatorName",
     "ServiceNameType",
@@ -56,6 +61,7 @@ __all__ = (
     "ServiceName",
     "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -90,8 +96,10 @@ InsightSeverityType = Literal["HIGH", "LOW", "MEDIUM"]
 InsightStatusType = Literal["CLOSED", "ONGOING"]
 InsightTypeType = Literal["PROACTIVE", "REACTIVE"]
 ListAnomaliesForInsightPaginatorName = Literal["list_anomalies_for_insight"]
+ListAnomalousLogGroupsPaginatorName = Literal["list_anomalous_log_groups"]
 ListEventsPaginatorName = Literal["list_events"]
 ListInsightsPaginatorName = Literal["list_insights"]
+ListMonitoredResourcesPaginatorName = Literal["list_monitored_resources"]
 ListNotificationChannelsPaginatorName = Literal["list_notification_channels"]
 ListOrganizationInsightsPaginatorName = Literal["list_organization_insights"]
 ListRecommendationsPaginatorName = Literal["list_recommendations"]
@@ -108,11 +116,23 @@ LocaleType = Literal[
     "ZH_CN",
     "ZH_TW",
 ]
+LogAnomalyTypeType = Literal[
+    "BLOCK_FORMAT",
+    "FORMAT",
+    "HTTP_CODE",
+    "KEYWORD",
+    "KEYWORD_TOKEN",
+    "NEW_FIELD_NAME",
+    "NUMERICAL_NAN",
+    "NUMERICAL_POINT",
+]
 OptInStatusType = Literal["DISABLED", "ENABLED"]
 OrganizationResourceCollectionTypeType = Literal[
     "AWS_ACCOUNT", "AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"
 ]
 ResourceCollectionTypeType = Literal["AWS_CLOUD_FORMATION", "AWS_SERVICE", "AWS_TAGS"]
+ResourcePermissionType = Literal["FULL_PERMISSION", "MISSING_PERMISSION"]
+ResourceTypeFilterType = Literal["LOG_GROUPS"]
 SearchInsightsPaginatorName = Literal["search_insights"]
 SearchOrganizationInsightsPaginatorName = Literal["search_organization_insights"]
 ServiceNameType = Literal[
@@ -214,6 +234,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -324,6 +345,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -380,11 +402,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -470,11 +494,24 @@ PaginatorName = Literal[
     "get_cost_estimation",
     "get_resource_collection",
     "list_anomalies_for_insight",
+    "list_anomalous_log_groups",
     "list_events",
     "list_insights",
+    "list_monitored_resources",
     "list_notification_channels",
     "list_organization_insights",
     "list_recommendations",
     "search_insights",
     "search_organization_insights",
 ]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-west-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-2",
+]
