@@ -15,8 +15,10 @@ Usage::
         GetCostEstimationPaginator,
         GetResourceCollectionPaginator,
         ListAnomaliesForInsightPaginator,
+        ListAnomalousLogGroupsPaginator,
         ListEventsPaginator,
         ListInsightsPaginator,
+        ListMonitoredResourcesPaginator,
         ListNotificationChannelsPaginator,
         ListOrganizationInsightsPaginator,
         ListRecommendationsPaginator,
@@ -32,8 +34,10 @@ Usage::
     get_cost_estimation_paginator: GetCostEstimationPaginator = client.get_paginator("get_cost_estimation")
     get_resource_collection_paginator: GetResourceCollectionPaginator = client.get_paginator("get_resource_collection")
     list_anomalies_for_insight_paginator: ListAnomaliesForInsightPaginator = client.get_paginator("list_anomalies_for_insight")
+    list_anomalous_log_groups_paginator: ListAnomalousLogGroupsPaginator = client.get_paginator("list_anomalous_log_groups")
     list_events_paginator: ListEventsPaginator = client.get_paginator("list_events")
     list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
+    list_monitored_resources_paginator: ListMonitoredResourcesPaginator = client.get_paginator("list_monitored_resources")
     list_notification_channels_paginator: ListNotificationChannelsPaginator = client.get_paginator("list_notification_channels")
     list_organization_insights_paginator: ListOrganizationInsightsPaginator = client.get_paginator("list_organization_insights")
     list_recommendations_paginator: ListRecommendationsPaginator = client.get_paginator("list_recommendations")
@@ -43,8 +47,7 @@ Usage::
 """
 from typing import Generic, Iterator, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     InsightTypeType,
@@ -58,10 +61,13 @@ from .type_defs import (
     GetCostEstimationResponseTypeDef,
     GetResourceCollectionResponseTypeDef,
     ListAnomaliesForInsightResponseTypeDef,
+    ListAnomalousLogGroupsResponseTypeDef,
     ListEventsFiltersTypeDef,
     ListEventsResponseTypeDef,
     ListInsightsResponseTypeDef,
     ListInsightsStatusFilterTypeDef,
+    ListMonitoredResourcesFiltersTypeDef,
+    ListMonitoredResourcesResponseTypeDef,
     ListNotificationChannelsResponseTypeDef,
     ListOrganizationInsightsResponseTypeDef,
     ListRecommendationsResponseTypeDef,
@@ -79,8 +85,10 @@ __all__ = (
     "GetCostEstimationPaginator",
     "GetResourceCollectionPaginator",
     "ListAnomaliesForInsightPaginator",
+    "ListAnomalousLogGroupsPaginator",
     "ListEventsPaginator",
     "ListInsightsPaginator",
+    "ListMonitoredResourcesPaginator",
     "ListNotificationChannelsPaginator",
     "ListOrganizationInsightsPaginator",
     "ListRecommendationsPaginator",
@@ -99,7 +107,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class DescribeOrganizationResourceCollectionHealthPaginator(Boto3Paginator):
+class DescribeOrganizationResourceCollectionHealthPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeOrganizationResourceCollectionHealth)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#describeorganizationresourcecollectionhealthpaginator)
@@ -120,7 +128,7 @@ class DescribeOrganizationResourceCollectionHealthPaginator(Boto3Paginator):
         """
 
 
-class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
+class DescribeResourceCollectionHealthPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#describeresourcecollectionhealthpaginator)
@@ -138,7 +146,7 @@ class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
         """
 
 
-class GetCostEstimationPaginator(Boto3Paginator):
+class GetCostEstimationPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#getcostestimationpaginator)
@@ -153,7 +161,7 @@ class GetCostEstimationPaginator(Boto3Paginator):
         """
 
 
-class GetResourceCollectionPaginator(Boto3Paginator):
+class GetResourceCollectionPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#getresourcecollectionpaginator)
@@ -171,7 +179,7 @@ class GetResourceCollectionPaginator(Boto3Paginator):
         """
 
 
-class ListAnomaliesForInsightPaginator(Boto3Paginator):
+class ListAnomaliesForInsightPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listanomaliesforinsightpaginator)
@@ -191,7 +199,22 @@ class ListAnomaliesForInsightPaginator(Boto3Paginator):
         """
 
 
-class ListEventsPaginator(Boto3Paginator):
+class ListAnomalousLogGroupsPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomalousLogGroups)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listanomalousloggroupspaginator)
+    """
+
+    def paginate(
+        self, *, InsightId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAnomalousLogGroupsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomalousLogGroups.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listanomalousloggroupspaginator)
+        """
+
+
+class ListEventsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listeventspaginator)
@@ -210,7 +233,7 @@ class ListEventsPaginator(Boto3Paginator):
         """
 
 
-class ListInsightsPaginator(Boto3Paginator):
+class ListInsightsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listinsightspaginator)
@@ -228,7 +251,25 @@ class ListInsightsPaginator(Boto3Paginator):
         """
 
 
-class ListNotificationChannelsPaginator(Boto3Paginator):
+class ListMonitoredResourcesPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListMonitoredResources)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listmonitoredresourcespaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        Filters: ListMonitoredResourcesFiltersTypeDef,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListMonitoredResourcesResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListMonitoredResources.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listmonitoredresourcespaginator)
+        """
+
+
+class ListNotificationChannelsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listnotificationchannelspaginator)
@@ -243,7 +284,7 @@ class ListNotificationChannelsPaginator(Boto3Paginator):
         """
 
 
-class ListOrganizationInsightsPaginator(Boto3Paginator):
+class ListOrganizationInsightsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListOrganizationInsights)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listorganizationinsightspaginator)
@@ -263,7 +304,7 @@ class ListOrganizationInsightsPaginator(Boto3Paginator):
         """
 
 
-class ListRecommendationsPaginator(Boto3Paginator):
+class ListRecommendationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#listrecommendationspaginator)
@@ -283,7 +324,7 @@ class ListRecommendationsPaginator(Boto3Paginator):
         """
 
 
-class SearchInsightsPaginator(Boto3Paginator):
+class SearchInsightsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#searchinsightspaginator)
@@ -303,7 +344,7 @@ class SearchInsightsPaginator(Boto3Paginator):
         """
 
 
-class SearchOrganizationInsightsPaginator(Boto3Paginator):
+class SearchOrganizationInsightsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchOrganizationInsights)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/paginators/#searchorganizationinsightspaginator)
