@@ -31,13 +31,19 @@ from .literals import (
     InsightStatusType,
     InsightTypeType,
     LocaleType,
+    LogAnomalyTypeType,
     OptInStatusType,
     OrganizationResourceCollectionTypeType,
     ResourceCollectionTypeType,
+    ResourcePermissionType,
     ServiceNameType,
     UpdateResourceCollectionActionType,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -79,9 +85,15 @@ __all__ = (
     "GetResourceCollectionRequestRequestTypeDef",
     "InsightTimeRangeTypeDef",
     "StartTimeRangeTypeDef",
+    "ListAnomalousLogGroupsRequestRequestTypeDef",
     "ListInsightsOngoingStatusFilterTypeDef",
+    "ListMonitoredResourcesFiltersTypeDef",
+    "MonitoredResourceIdentifierTypeDef",
     "ListNotificationChannelsRequestRequestTypeDef",
     "ListRecommendationsRequestRequestTypeDef",
+    "LogAnomalyClassTypeDef",
+    "LogsAnomalyDetectionIntegrationConfigTypeDef",
+    "LogsAnomalyDetectionIntegrationTypeDef",
     "SnsChannelConfigTypeDef",
     "OpsCenterIntegrationConfigTypeDef",
     "OpsCenterIntegrationTypeDef",
@@ -116,12 +128,17 @@ __all__ = (
     "DescribeResourceCollectionHealthRequestDescribeResourceCollectionHealthPaginateTypeDef",
     "GetCostEstimationRequestGetCostEstimationPaginateTypeDef",
     "GetResourceCollectionRequestGetResourceCollectionPaginateTypeDef",
+    "ListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef",
     "ListNotificationChannelsRequestListNotificationChannelsPaginateTypeDef",
     "ListRecommendationsRequestListRecommendationsPaginateTypeDef",
     "ListInsightsClosedStatusFilterTypeDef",
     "ListAnomaliesForInsightRequestListAnomaliesForInsightPaginateTypeDef",
     "ListAnomaliesForInsightRequestRequestTypeDef",
     "ListInsightsAnyStatusFilterTypeDef",
+    "ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
+    "ListMonitoredResourcesRequestRequestTypeDef",
+    "ListMonitoredResourcesResponseTypeDef",
+    "LogAnomalyShowcaseTypeDef",
     "NotificationChannelConfigTypeDef",
     "UpdateServiceIntegrationConfigTypeDef",
     "ServiceIntegrationConfigTypeDef",
@@ -138,6 +155,7 @@ __all__ = (
     "GetCostEstimationResponseTypeDef",
     "StartCostEstimationRequestRequestTypeDef",
     "ListInsightsStatusFilterTypeDef",
+    "AnomalousLogGroupTypeDef",
     "AddNotificationChannelRequestRequestTypeDef",
     "NotificationChannelTypeDef",
     "UpdateServiceIntegrationRequestRequestTypeDef",
@@ -162,6 +180,7 @@ __all__ = (
     "ListInsightsRequestRequestTypeDef",
     "ListOrganizationInsightsRequestListOrganizationInsightsPaginateTypeDef",
     "ListOrganizationInsightsRequestRequestTypeDef",
+    "ListAnomalousLogGroupsResponseTypeDef",
     "ListNotificationChannelsResponseTypeDef",
     "PerformanceInsightsReferenceComparisonValuesTypeDef",
     "RecommendationTypeDef",
@@ -620,6 +639,29 @@ StartTimeRangeTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredListAnomalousLogGroupsRequestRequestTypeDef = TypedDict(
+    "_RequiredListAnomalousLogGroupsRequestRequestTypeDef",
+    {
+        "InsightId": str,
+    },
+)
+_OptionalListAnomalousLogGroupsRequestRequestTypeDef = TypedDict(
+    "_OptionalListAnomalousLogGroupsRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAnomalousLogGroupsRequestRequestTypeDef(
+    _RequiredListAnomalousLogGroupsRequestRequestTypeDef,
+    _OptionalListAnomalousLogGroupsRequestRequestTypeDef,
+):
+    pass
+
+
 ListInsightsOngoingStatusFilterTypeDef = TypedDict(
     "ListInsightsOngoingStatusFilterTypeDef",
     {
@@ -627,6 +669,24 @@ ListInsightsOngoingStatusFilterTypeDef = TypedDict(
     },
 )
 
+ListMonitoredResourcesFiltersTypeDef = TypedDict(
+    "ListMonitoredResourcesFiltersTypeDef",
+    {
+        "ResourcePermission": ResourcePermissionType,
+        "ResourceTypeFilters": Sequence[Literal["LOG_GROUPS"]],
+    },
+)
+
+MonitoredResourceIdentifierTypeDef = TypedDict(
+    "MonitoredResourceIdentifierTypeDef",
+    {
+        "MonitoredResourceName": str,
+        "Type": str,
+        "ResourcePermission": ResourcePermissionType,
+    },
+    total=False,
+)
+
 ListNotificationChannelsRequestRequestTypeDef = TypedDict(
     "ListNotificationChannelsRequestRequestTypeDef",
     {
@@ -659,6 +719,36 @@ class ListRecommendationsRequestRequestTypeDef(
     pass
 
 
+LogAnomalyClassTypeDef = TypedDict(
+    "LogAnomalyClassTypeDef",
+    {
+        "LogStreamName": str,
+        "LogAnomalyType": LogAnomalyTypeType,
+        "LogAnomalyToken": str,
+        "LogEventId": str,
+        "Explanation": str,
+        "NumberOfLogLinesOccurrences": int,
+        "LogEventTimestamp": datetime,
+    },
+    total=False,
+)
+
+LogsAnomalyDetectionIntegrationConfigTypeDef = TypedDict(
+    "LogsAnomalyDetectionIntegrationConfigTypeDef",
+    {
+        "OptInStatus": OptInStatusType,
+    },
+    total=False,
+)
+
+LogsAnomalyDetectionIntegrationTypeDef = TypedDict(
+    "LogsAnomalyDetectionIntegrationTypeDef",
+    {
+        "OptInStatus": OptInStatusType,
+    },
+    total=False,
+)
+
 SnsChannelConfigTypeDef = TypedDict(
     "SnsChannelConfigTypeDef",
     {
@@ -1010,6 +1100,28 @@ class GetResourceCollectionRequestGetResourceCollectionPaginateTypeDef(
     pass
 
 
+_RequiredListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef = TypedDict(
+    "_RequiredListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef",
+    {
+        "InsightId": str,
+    },
+)
+_OptionalListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef = TypedDict(
+    "_OptionalListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef(
+    _RequiredListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef,
+    _OptionalListAnomalousLogGroupsRequestListAnomalousLogGroupsPaginateTypeDef,
+):
+    pass
+
+
 ListNotificationChannelsRequestListNotificationChannelsPaginateTypeDef = TypedDict(
     "ListNotificationChannelsRequestListNotificationChannelsPaginateTypeDef",
     {
@@ -1107,6 +1219,68 @@ ListInsightsAnyStatusFilterTypeDef = TypedDict(
     },
 )
 
+_RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef = TypedDict(
+    "_RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
+    {
+        "Filters": ListMonitoredResourcesFiltersTypeDef,
+    },
+)
+_OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef = TypedDict(
+    "_OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef(
+    _RequiredListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef,
+    _OptionalListMonitoredResourcesRequestListMonitoredResourcesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListMonitoredResourcesRequestRequestTypeDef = TypedDict(
+    "_RequiredListMonitoredResourcesRequestRequestTypeDef",
+    {
+        "Filters": ListMonitoredResourcesFiltersTypeDef,
+    },
+)
+_OptionalListMonitoredResourcesRequestRequestTypeDef = TypedDict(
+    "_OptionalListMonitoredResourcesRequestRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+
+class ListMonitoredResourcesRequestRequestTypeDef(
+    _RequiredListMonitoredResourcesRequestRequestTypeDef,
+    _OptionalListMonitoredResourcesRequestRequestTypeDef,
+):
+    pass
+
+
+ListMonitoredResourcesResponseTypeDef = TypedDict(
+    "ListMonitoredResourcesResponseTypeDef",
+    {
+        "MonitoredResourceIdentifiers": List[MonitoredResourceIdentifierTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+LogAnomalyShowcaseTypeDef = TypedDict(
+    "LogAnomalyShowcaseTypeDef",
+    {
+        "LogAnomalyClasses": List[LogAnomalyClassTypeDef],
+    },
+    total=False,
+)
+
 NotificationChannelConfigTypeDef = TypedDict(
     "NotificationChannelConfigTypeDef",
     {
@@ -1118,6 +1292,7 @@ UpdateServiceIntegrationConfigTypeDef = TypedDict(
     "UpdateServiceIntegrationConfigTypeDef",
     {
         "OpsCenter": OpsCenterIntegrationConfigTypeDef,
+        "LogsAnomalyDetection": LogsAnomalyDetectionIntegrationConfigTypeDef,
     },
     total=False,
 )
@@ -1126,6 +1301,7 @@ ServiceIntegrationConfigTypeDef = TypedDict(
     "ServiceIntegrationConfigTypeDef",
     {
         "OpsCenter": OpsCenterIntegrationTypeDef,
+        "LogsAnomalyDetection": LogsAnomalyDetectionIntegrationTypeDef,
     },
     total=False,
 )
@@ -1268,6 +1444,18 @@ ListInsightsStatusFilterTypeDef = TypedDict(
     total=False,
 )
 
+AnomalousLogGroupTypeDef = TypedDict(
+    "AnomalousLogGroupTypeDef",
+    {
+        "LogGroupName": str,
+        "ImpactStartTime": datetime,
+        "ImpactEndTime": datetime,
+        "NumberOfLogLinesScanned": int,
+        "LogAnomalyShowcases": List[LogAnomalyShowcaseTypeDef],
+    },
+    total=False,
+)
+
 AddNotificationChannelRequestRequestTypeDef = TypedDict(
     "AddNotificationChannelRequestRequestTypeDef",
     {
@@ -1595,6 +1783,16 @@ class ListOrganizationInsightsRequestRequestTypeDef(
     pass
 
 
+ListAnomalousLogGroupsResponseTypeDef = TypedDict(
+    "ListAnomalousLogGroupsResponseTypeDef",
+    {
+        "InsightId": str,
+        "AnomalousLogGroups": List[AnomalousLogGroupTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 ListNotificationChannelsResponseTypeDef = TypedDict(
     "ListNotificationChannelsResponseTypeDef",
     {
